//// Constantes

// Ressources plugins
const 	gulp 			= require('gulp'),
		minifycss 		= require('gulp-clean-css'),
		uglify 			= require('gulp-uglify'),
		concat  		= require('gulp-concat'),
		browserSync 	= require('browser-sync').create();





//// Fonctions / sous tâches

// Copier les ressources dans le nouveau dossier
gulp.task('copy-assets', function() {

	return gulp.src( [
			// On copie tout... 
			'src/**/*.*',

			// sauf le css, qui sera copié via minify css
			'!src/css/**/*.css',
			// sauf le js, qui sera copié via uglify js
			'!src/js/**/*.js'
			]
		)
		// On met dans le tuyau (c'est comme ça, chut)
		// 		   On envoie les fichiers dans le dossier build/
		.pipe(gulp.dest('build/'));
});


// Copier le html, pour les mises à jour avec browser-sync
gulp.task('copy-html', function() {
	return gulp.src( 'src/**/*.html')
		.pipe(gulp.dest('build/'))

		// On met à jour le navigateur
		.pipe(browserSync.stream());
});


// Minifier le css
// https://www.npmjs.com/package/gulp-clean-css
gulp.task('minify-css', function() {
	return gulp.src('src/css/**/*.css')
		// on minifie l'ensemble des fichiers
		.pipe(minifycss())
		// on les regroupe en un seul
		.pipe(concat('main.css'))
		.pipe(gulp.dest('build/css/'))

		// On met à jour le navigateur
		.pipe(browserSync.stream());
});


// Minifier le js
gulp.task('minify-js', function () {
	return gulp.src('src/js/**/*.js')
	// on minifie l'ensemble des fichiers
		.pipe(uglify())
		// on les regroupe en un seul
		.pipe(concat('main.js'))
		.pipe(gulp.dest('build/js/'))

		// On met à jour le navigateur
		.pipe(browserSync.stream());
});





//// Tâches

// Fonction par défaut, appelée dans la console en tapant 'gulp'
//		Le premier paramètre est le nom de la tâche
//		Cette tâche appelle chaque tâche contenue dans le tableau passé en 2eme paramètre

//  	La tâche par défaut appelle la tâche copy-assets, ainsi que la tâche minifier le css
gulp.task('default', [ 'copy-assets', 'minify-css', 'minify-js']);

//// Watch, actualisation à la modification
// On éxécute la tâche par défaut avant, puis..
gulp.task('watch', ['default'], function() {

	// On lanc eun serveur local js
    browserSync.init({
        server: "./build"
    });

    // On écoute les changements de fichiers html/css/js,
    // puis on apelle leur tâches correspondantes en cas de modifications
    gulp.watch("src/**/*.html", 	['copy-html']);
    
    gulp.watch("src/css/**/*.css", 	['minify-css']);

    gulp.watch("src/js/**/*.js", 	['minify-js']);

    gulp.watch("src/*.html").on('change', browserSync.reload);
});
